@@ -24,6 +24,7 @@ from falcon import testing
 import mock
 
 from monasca_log_api.reference.common import log_publisher
+from monasca_log_api.reference.common import model
 from monasca_log_api.tests import base
 
 EPOCH_START = datetime.datetime(1970, 1, 1)
@@ -122,8 +123,9 @@ class TestSendMessage(testing.TestBase):
         dimension_1_value = '50'
         dimension_2_name = 'cpu_time'
         dimension_2_value = '60'
-        msg = {
-            'log': {
+
+        msg = model.Envelope(
+            log={
                 'message': 1,
                 'application_type': application_type,
                 'dimensions': {
@@ -131,12 +133,11 @@ class TestSendMessage(testing.TestBase):
                     dimension_2_name: dimension_2_value
                 }
             },
-            'creation_time': creation_time,
-            'meta': {
+            meta={
                 'tenantId': 1
             }
-        }
-
+        )
+        msg['creation_time'] = creation_time
         instance.send_message(msg)
 
         instance._kafka_publisher.publish.assert_called_once_with(
@@ -162,8 +163,8 @@ class TestSendMessage(testing.TestBase):
         dimension_2_name = 'cpu_time'
         dimension_2_value = '60'
         application_type = 'monasca-log-api'
-        msg = {
-            'log': {
+        msg = model.Envelope(
+            log={
                 'message': 1,
                 'application_type': application_type,
                 'dimensions': {
@@ -171,11 +172,11 @@ class TestSendMessage(testing.TestBase):
                     dimension_2_name: dimension_2_value
                 }
             },
-            'creation_time': creation_time,
-            'meta': {
+            meta={
                 'tenantId': 1
             }
-        }
+        )
+        msg['creation_time'] = creation_time
         json_msg = ujson.dumps(msg)
 
         instance.send_message(msg)
@@ -188,6 +189,9 @@ class TestSendMessage(testing.TestBase):
                 [json_msg])
 
 
+@mock.patch(
+    'monasca_log_api.reference.common.log_publisher.producer'
+    '.KafkaProducer')
 class TestTruncation(testing.TestBase):
     EXTRA_CHARS_SIZE = len(bytearray(ujson.dumps({
         'log': {
@@ -203,24 +207,15 @@ class TestTruncation(testing.TestBase):
         super(TestTruncation, self).setUp()
         self._conf = base.mock_config(self)
 
-    @mock.patch(
-        'monasca_log_api.reference.common.log_publisher.producer'
-        '.KafkaProducer')
     def test_should_not_truncate_message_if_size_is_smaller(self, _):
         diff_size = random.randint(1, 100)
         self._run_truncate_test(log_size_factor=-diff_size,
                                 truncate_by=0)
 
-    @mock.patch(
-        'monasca_log_api.reference.common.log_publisher.producer'
-        '.KafkaProducer')
     def test_should_not_truncate_message_if_size_equal_to_max(self, _):
         self._run_truncate_test(log_size_factor=0,
                                 truncate_by=0)
 
-    @mock.patch(
-        'monasca_log_api.reference.common.log_publisher.producer'
-        '.KafkaProducer')
     def test_should_truncate_too_big_message(self, _):
         diff_size = random.randint(1, 100)
         max_size = 1000
@@ -258,6 +253,7 @@ class TestTruncation(testing.TestBase):
         }
 
         instance = log_publisher.LogPublisher()
+        instance._logs_truncated_gauge.send = meter = mock.Mock()
 
         envelope_copy = copy.deepcopy(envelope)
         json_envelope = instance._truncate(envelope_copy)
@@ -275,3 +271,5 @@ class TestTruncation(testing.TestBase):
                              parsed_log_message)
 
         self.assertEqual(expected_log_message_size, parsed_log_message_len)
+        self.assertEqual(1, meter.call_count)
+        self.assertEqual(truncate_by, meter.mock_calls[0][2]['value'])
